ModernGL
========

ModernGL is a high performance rendering module for Python.

.. toctree::
    :maxdepth: 2

    installation.rst
    reference/index.rst
    the_guide/index.rst
    misc/index.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
